==> qtools_profiler-2.2.x-dev.tar.gz: qtools_profiler/src/Controller/RequestReportController.php <==
<?php

namespace Drupal\qtools_profiler\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Render\HtmlResponse;
use Drupal\Core\Render\RendererInterface;
use Drupal\qtools_profiler\Ajax\PreviewSummaryCommand;
use Drupal\qtools_profiler\PerformanceService;
use Drupal\qtools_profiler\ReportService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class RequestReportController.
 */
class RequestReportController extends ControllerBase {

  /**
   * Drupal\qtools_profiler\PerformanceService.
   *
   * @var \Drupal\qtools_profiler\PerformanceService
   */
  protected $performanceService;

  /**
   * Drupal\qtools_profiler\ReportService.
   *
   * @var \Drupal\qtools_profiler\ReportService
   */
  protected $reportService;

  /**
   * Drupal\Core\Form\FormBuilderInterface.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Drupal\Core\Extension\ModuleHandlerInterface.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * ExtensionPathResolver.
   *
   * @var \Drupal\Core\Extension\ExtensionPathResolver
   */
  protected $extensionPathResolver;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    PerformanceService $performanceService,
    ReportService $reportService,
    FormBuilderInterface $formBuilder,
    ModuleHandlerInterface $moduleHandler,
    RendererInterface $renderer,
    ExtensionPathResolver $extensionPathResolver,
  ) {
    $this->performanceService = $performanceService;
    $this->reportService = $reportService;
    $this->formBuilder = $formBuilder;
    $this->moduleHandler = $moduleHandler;
    $this->renderer = $renderer;
    $this->extensionPathResolver = $extensionPathResolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('qtools_profiler.performance'),
      $container->get('qtools_profiler.report'),
      $container->get('form_builder'),
      $container->get('module_handler'),
      $container->get('renderer'),
      $container->get('extension.path.resolver'),
    );
  }

  /**
   * Returns page content.
   *
   * @return array
   *   Page array.
   */
  public function pageBuild(Request $request) {

    // Get filter values.
    $route = $request->query->get('route');

    // Get filter form.
    $build['form'] = $this->formBuilder->getForm('\Drupal\qtools_profiler\Form\ReportFilterForm');

    // Get report table.
    $filters = [
      'route' => $route,
    ] + $this->reportService->getReportFilters();
    $header = $this->reportService->reportRequestTableHeader($filters);
    $query = $this->reportService->reportRequestBaseQuery($filters);
    $results = $query->execute()->fetchAll();
    $rows = $this->reportService->reportRequestProcessResults($results, $filters);

    $build['table'] = [
      '#type' => 'table',
      '#rows' => $rows,
      '#header' => $header,
      '#cache' => [
        'max-age' => -1,
      ],
    ];

    $build['pager'] = [
      '#type' => 'pager',
    ];

    return $build;
  }

  /**
   * Returns detailed profile page.
   *
   * @return array
   *   Page array.
   */
  public function pageBuildProfile(Request $request, $id) {
    return $this->performanceService->buildProfilePage($request, $id);
  }

  /**
   * Returns request summary.
   */
  public function previewSummary(Request $request, $id, $tracking_id) {
    // Prepare list of requests we need to get info for.
    $params[$id] = $tracking_id;
    $response = new AjaxResponse();

    // Get all pending redirect ids.
    $ids = $this->performanceService->getRedirectIds();
    foreach ($ids as $redirectId) {
      $params[$redirectId] = NULL;
    }

    // Push info about all requests.
    foreach ($params as $rid => $tid) {
      $name = $this->performanceService->getRequestName($rid);
      $summary = $this->performanceService->getRequestSummary($rid);
      $response->addCommand(new PreviewSummaryCommand($tid, $rid, NULL, $name, $summary));
    }

    // Gather additional commands to send with preview info response.
    $this->moduleHandler->alter(PerformanceService::HOOK_REQUEST_SUMMARY_RESPONSE_ALTER, $response, $id);

    return $response;
  }

  /**
   * Returns preview app summary.
   */
  public function previewApp(Request $request) {
    if (FALSE) {
      $build_path = '/' . $this->extensionPathResolver->getPath('module', 'qtools_profiler') . '/react-app/chrome-extension/build';
      $build = [
        '#theme' => 'qtools_profiler_preview_react',
        '#build_path' => $build_path,
      ];
    }
    else {
      $build_path = '/' . $this->extensionPathResolver->getPath('module', 'qtools_profiler') . '/vue-app/dist/spa';
      $build = [
        '#theme' => 'qtools_profiler_preview_vue',
        '#build_path' => $build_path,
      ];
    }

    $response = new HtmlResponse();
    $response->setContent($this->renderer->renderRoot($build));

    return $response;
  }

  /**
   * Returns preview app summary.
   */
  public function previewVueApp(Request $request) {
    $module_path = $this->extensionPathResolver->getPath('module', 'qtools_profiler');
    $build_path = $module_path . '/vue-app/dist/spa';
    $content = file_get_contents($build_path . '/index.html');

    $content = strtr($content, [
      'src=' => 'src=/' . $build_path . '/',
      'href=' => 'href=/' . $build_path . '/',
    ]);

    $response = new HtmlResponse();
    $response->setContent($content);

    return $response;
  }

}

==> qtools_profiler-3.0.x-dev.tar.gz: qtools_profiler/src/Controller/RequestReportController.php <==
<?php

namespace Drupal\qtools_profiler\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Render\HtmlResponse;
use Drupal\Core\Render\RendererInterface;
use Drupal\qtools_profiler\Ajax\PreviewSummaryCommand;
use Drupal\qtools_profiler\PerformanceService;
use Drupal\qtools_profiler\ReportService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class RequestReportController.
 */
class RequestReportController extends ControllerBase {

  /**
   * {@inheritdoc}
   */
  public function __construct(
    protected PerformanceService $performanceService,
    protected ReportService $reportService,
    protected RendererInterface $renderer,
    protected ExtensionPathResolver $extensionPathResolver,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get(PerformanceService::class),
      $container->get(ReportService::class),
      $container->get('renderer'),
      $container->get('extension.path.resolver'),
    );
  }

  /**
   * Returns page content.
   *
   * @return array
   *   Page array.
   */
  public function pageBuild(Request $request) {

    // Get filter values.
    $route = $request->query->get('route');

    // Get filter form.
    $build['form'] = $this->formBuilder()->getForm('\Drupal\qtools_profiler\Form\ReportFilterForm');

    // Get report table.
    $filters = [
      'route' => $route,
    ] + $this->reportService->getReportFilters();
    $header = $this->reportService->reportRequestTableHeader($filters);
    $query = $this->reportService->reportRequestBaseQuery($filters);
    $results = $query->execute()->fetchAll();
    $rows = $this->reportService->reportRequestProcessResults($results, $filters);

    $build['table'] = [
      '#type' => 'table',
      '#rows' => $rows,
      '#header' => $header,
      '#cache' => [
        'max-age' => -1,
      ],
    ];

    $build['pager'] = [
      '#type' => 'pager',
    ];

    return $build;
  }

  /**
   * Returns detailed profile page.
   *
   * @return array
   *   Page array.
   */
  public function pageBuildProfile(Request $request, $id) {
    return $this->performanceService->buildProfilePage($request, $id);
  }

  /**
   * Returns request summary.
   */
  public function previewSummary(Request $request, $id, $tracking_id) {
    // Prepare list of requests we need to get info for.
    $params[$id] = $tracking_id;
    $response = new AjaxResponse();

    // Get all pending redirect ids.
    $ids = $this->performanceService->getRedirectIds();
    foreach ($ids as $redirectId) {
      $params[$redirectId] = NULL;
    }

    // Push info about all requests.
    foreach ($params as $rid => $tid) {
      $name = $this->performanceService->getRequestName($rid);
      $summary = $this->performanceService->getRequestSummary($rid);
      $response->addCommand(new PreviewSummaryCommand($tid, $rid, NULL, $name, $summary));
    }

    // Gather additional commands to send with preview info response.
    $this->moduleHandler()->alter(PerformanceService::HOOK_REQUEST_SUMMARY_RESPONSE_ALTER, $response, $id);

    return $response;
  }

  /**
   * Returns preview app summary.
   */
  public function previewApp(Request $request) {
    if (FALSE) {
      $build_path = '/' . $this->extensionPathResolver->getPath('module', 'qtools_profiler') . '/react-app/chrome-extension/build';
      $build = [
        '#theme' => 'qtools_profiler_preview_react',
        '#build_path' => $build_path,
      ];
    }
    else {
      $build_path = '/' . $this->extensionPathResolver->getPath('module', 'qtools_profiler') . '/vue-app/dist/spa';
      $build = [
        '#theme' => 'qtools_profiler_preview_vue',
        '#build_path' => $build_path,
      ];
    }

    $response = new HtmlResponse();
    $response->setContent($this->renderer->renderRoot($build));

    return $response;
  }

  /**
   * Returns preview app summary.
   */
  public function previewVueApp(Request $request) {
    $module_path = $this->extensionPathResolver->getPath('module', 'qtools_profiler');
    $build_path = $module_path . '/vue-app/dist/spa';
    $content = file_get_contents($build_path . '/index.html');

    $content = strtr($content, [
      'src=' => 'src=/' . $build_path . '/',
      'href=' => 'href=/' . $build_path . '/',
    ]);

    $response = new HtmlResponse();
    $response->setContent($content);

    return $response;
  }

}
